=======
Credits
=======

Founding Father
---------------

* Vitaly Babiy <vbabiy86@gmail.com>


Development Lead
----------------

* Dominik Kozaczko <dominik@kozaczko.info>


Contributors
------------

* Rense VanderHoek <rense@me.com>
* Jakob Oswald <jakob.oswald@gmx.net>
* Yavor Atov <yavor.atov@gmail.com>
* Danilo Bargen <mail@dbrgn.ch>
* Jevgenij Tsoi <jevgenij@virtusize.com>
